.. _over_sampling_ref:

Over-sampling methods
=====================

.. automodule:: imblearn.over_sampling
    :no-members:
    :no-inherited-members:

.. currentmodule:: imblearn.over_sampling

Basic over-sampling
-------------------

.. autosummary::
   :toctree: generated/
   :template: class.rst

   RandomOverSampler

SMOTE algorithms
----------------

.. autosummary::
   :toctree: generated/
   :template: class.rst

   SMOTE
   SMOTENC
   SMOTEN
   ADASYN
   BorderlineSMOTE
   KMeansSMOTE
   SVMSMOTE
